@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -674,6 +674,17 @@ ssl_cert = <{$fullchain}
 ssl_key = <{$keyfile}
 EOSSL;
 				file_put_contents($dovecot_conf, $ssl_content);
+			} elseif (Settings::IsInList('system.le_renew_services', 'dovecot24')) {
+					// custom config for dovecot
+					$ssl_content = <<<EOSSL
+# Autogenerated configuration by froxlor.
+# Do not manually edit this file as it will be overwritten.
+
+ssl = yes
+ssl_server_cert_file = {$fullchain}
+ssl_server_key_file = {$keyfile}
+EOSSL;
+					file_put_contents($dovecot_conf, $ssl_content);
 			} elseif (file_exists($dovecot_conf)) {
 				// safely remove the autogenerated config file
 				unlink($dovecot_conf);
