@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -33,7 +33,6 @@ return [
 		'sections' => [
 			'section_a' => [
 				'title' => lng('admin.ipsandports.ipandport'),
-				'image' => 'icons/ipsports_add.png',
 				'fields' => [
 					'ip' => [
 						'label' => lng('admin.ipsandports.ip'),
@@ -53,7 +52,6 @@ return [
 			],
 			'section_b' => [
 				'title' => lng('admin.ipsandports.webserverdefaultconfig'),
-				'image' => 'icons/ipsports_edit.png',
 				'fields' => [
 					'listen_statement' => [
 						'visible' => Settings::Get('system.webserver') != 'nginx',
@@ -100,7 +98,6 @@ return [
 			],
 			'section_c' => [
 				'title' => lng('admin.ipsandports.webserverdomainconfig'),
-				'image' => 'icons/ipsports_edit.png',
 				'fields' => [
 					'default_vhostconf_domain' => [
 						'label' => lng('admin.ipsandports.default_vhostconf_domain'),
@@ -129,7 +126,6 @@ return [
 			],
 			'section_d' => [
 				'title' => lng('admin.ipsandports.webserverssldomainconfig'),
-				'image' => 'icons/ipsports_edit.png',
 				'visible' => Settings::Get('system.use_ssl') == 1,
 				'fields' => [
 					'ssl' => [
